;; Generated package description from coterm.el  -*- no-byte-compile: t -*-
(define-package "coterm" "1.5.0.20220318.103500" "Terminal emulation for comint" '((emacs "26.1")) :commit "ef4b5fb55304266244c87d2c6aaefab58149da62" :authors '(("jakanakaevangeli" . "jakanakaevangeli@chiru.no")) :maintainer '("jakanakaevangeli" . "jakanakaevangeli@chiru.no") :keywords '("processes") :url "https://repo.or.cz/emacs-coterm.git")
